@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 1.06.
 package XML::Compile::Translate::Reader;
 use vars '$VERSION';
-$VERSION = '1.14';
+$VERSION = '1.15';
 
 use base 'XML::Compile::Translate';
 
@@ -34,11 +34,16 @@ use XML::Compile::Iterator ();
 sub actsAs($) { $_[1] eq 'READER' }
 
 sub makeTagUnqualified
-{   my ($self, $path, $node, $local, $ns) = @_;
-    $local =~ s/.*?\://;   # strip prefix, that's all
-    $local;
+{ # my ($self, $path, $node, $local, $ns) = @_;
+  # $local;
+    $_[3];
+}
+
+sub makeTagQualified
+{ # my ($self, $path, $node, $local, $ns) = @_;
+#   $_[0]->keyRewrite($_[4], $_[3]);
+    $_[3];
 }
-*makeTagQualified = \&makeTagUnqualified;
 
 sub typemapToHooks($$)
 {   my ($self, $hooks, $typemap) = @_;
@@ -598,8 +603,7 @@ sub makeElementAbstract
 
 sub makeComplexElement
 {   my ($self, $path, $tag, $elems, $attrs, $attrs_any) = @_;
-#my @e = @$elems;
-#my @a = @$attrs;
+#my @e = @$elems; my @a = @$attrs;
     my @elems = odd_elements @$elems;
     my @attrs = (odd_elements(@$attrs), @$attrs_any);
 
@@ -905,7 +909,7 @@ sub makeAttributeFixed
     my $def  = $do->($fixed);
 
     sub { my $node  = $_[0]->getAttributeNodeNS($ns, $tag)
-              or return ($tag => $def);
+              or return ($label => $def);
 
           my $value = $do->($node);
           defined $value && $value eq $def
