@@ -5,7 +5,7 @@
 
 package XML::Compile::Translate::Template;
 use vars '$VERSION';
-$VERSION = '1.14';
+$VERSION = '1.15';
 
 use base 'XML::Compile::Translate';
 
@@ -25,14 +25,15 @@ sub makeTagQualified
 {   my ($self, $path, $node, $local, $ns) = @_;
     my $prefix = $self->_registerNSprefix('', $ns, 1);
 
-      $self->{_output} eq 'PERL' ? $self->keyRewrite(pack_type $ns,$local)
+# it is certainly not correct to do a keyRewrite here, but it works :(
+      $self->{_output} eq 'PERL' ? $self->keyRewrite($ns, $local)
     : length $prefix             ? $prefix .':'. $local
     :                              $local;
 }
 
 sub makeTagUnqualified
 {   my ($self, $path, $node, $name) = @_;
-    $name =~ s/.*\://;
+#   $name =~ s/.*\://;
     $name;
 }
 
