@@ -5,7 +5,7 @@
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.14';
+$VERSION = '1.15';
 
 use base 'XML::Compile::Translate';
 
@@ -31,15 +31,17 @@ use XML::Compile::Util qw/pack_type unpack_type type_of_node SCHEMA2001i
 sub actsAs($) { $_[1] eq 'WRITER' }
 
 sub makeTagQualified
-{   my ($self, $path, $node, $local, $ns) = @_;
-    my $prefix = $self->_registerNSprefix('', $ns, 1);
-    length($prefix) ? "$prefix:$local" : $local;
+{ # my ($self, $path, $node, $local, $ns) = @_;
+  # my $prefix = $self->_registerNSprefix('', $ns, 1);
+  # length($prefix) ? "$prefix:$local" : $local;
+    my $prefix = $_[0]->_registerNSprefix('', $_[4], 1);
+    length($prefix) ? "$prefix:$_[3]" : $_[3];
 }
 
 sub makeTagUnqualified
-{   my ($self, $path, $node, $name) = @_;
-    $name =~ s/.*\://;
-    $name;
+{ # my ($self, $path, $node, $local, $ns) = @_;
+  # $local;
+    $_[3];
 }
 
 sub _typemapClass($$)
@@ -666,6 +668,7 @@ sub makeMixedElement
 
 sub makeSimpleElement
 {   my ($self, $path, $tag, $st) = @_;
+
     sub {
         my ($doc, $data) = @_;
         return $doc->importNode($data)
@@ -854,7 +857,7 @@ sub makeAttributeFixed
               or error __x"value of attribute `{tag}' is fixed to `{fixed}', not `{got}' at {path}"
                    , tag => $tag, got => $value, fixed => $fixed, path => $path;
 
-          $doc->createAttributeNS($ns, $tag, $fixed);
+          $doc->createAttribute($tag, $fixed);
         };
 }
 
